==> TACZ-Refabricated-1.20.1-0.0.3-forge1.1.6-hotfix-sources.jar: com/tacz/guns/client/input/ZoomKey.java <==
package com.tacz.guns.client.input;

import cn.sh1rocu.tacz.api.event.InputEvent;
import com.tacz.guns.api.client.gameplay.IClientPlayerGunOperator;
import com.tacz.guns.network.message.ClientMessagePlayerZoom;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import net.minecraft.class_746;
import org.lwjgl.glfw.GLFW;

import static com.tacz.guns.util.InputExtraCheck.isInGame;

@Environment(EnvType.CLIENT)
public class ZoomKey {
    public static final class_304 ZOOM_KEY = new class_304("key.tacz.zoom.desc",
            class_3675.class_307.field_1668,
            GLFW.GLFW_KEY_V,
            "key.category.tacz");

    public static void onZoomKeyPress(InputEvent.Key event) {
        if (isInGame() && event.getAction() == GLFW.GLFW_PRESS && ZOOM_KEY.method_1417(event.getKey(), event.getScanCode())) {
            doZoomLogic();
        }
    }

    public static void onZoomMousePress(InputEvent.MouseButton.Post event) {
        if (isInGame() && event.getAction() == GLFW.GLFW_PRESS && ZOOM_KEY.method_1433(event.getButton())) {
            doZoomLogic();
        }
    }

    public static boolean onZoomControllerPress(boolean isPress) {
        if (isInGame() && isPress) {
            class_746 player = class_310.method_1551().field_1724;
            if (player == null || player.method_7325()) {
                return false;
            }
            IClientPlayerGunOperator operator = IClientPlayerGunOperator.fromLocalPlayer(player);
            if (operator.isAim()) {
                ClientPlayNetworking.send(new ClientMessagePlayerZoom());
                return true;
            }
        }
        return false;
    }

    private static void doZoomLogic() {
        class_746 player = class_310.method_1551().field_1724;
        if (player == null || player.method_7325()) {
            return;
        }
        IClientPlayerGunOperator operator = IClientPlayerGunOperator.fromLocalPlayer(player);
        if (operator.isAim()) {
            ClientPlayNetworking.send(new ClientMessagePlayerZoom());
        }
    }
}

==> TACZ-Refabricated-1.21.1-0.0.2-forge1.1.6-hotfix-sources.jar: com/tacz/guns/client/input/ZoomKey.java <==
package com.tacz.guns.client.input;

import cn.sh1rocu.tacz.api.event.InputEvent;
import com.tacz.guns.api.client.gameplay.IClientPlayerGunOperator;
import com.tacz.guns.network.message.ClientMessagePlayerZoom;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import net.minecraft.class_746;
import org.lwjgl.glfw.GLFW;

import static com.tacz.guns.util.InputExtraCheck.isInGame;

@Environment(EnvType.CLIENT)
public class ZoomKey {
    public static final class_304 ZOOM_KEY = new class_304("key.tacz.zoom.desc",
            class_3675.class_307.field_1668,
            GLFW.GLFW_KEY_V,
            "key.category.tacz");

    public static void onZoomKeyPress(InputEvent.Key event) {
        if (isInGame() && event.getAction() == GLFW.GLFW_PRESS && ZOOM_KEY.method_1417(event.getKey(), event.getScanCode())) {
            doZoomLogic();
        }
    }

    public static void onZoomMousePress(InputEvent.MouseButton.Post event) {
        if (isInGame() && event.getAction() == GLFW.GLFW_PRESS && ZOOM_KEY.method_1433(event.getButton())) {
            doZoomLogic();
        }
    }

    public static boolean onZoomControllerPress(boolean isPress) {
        if (isInGame() && isPress) {
            class_746 player = class_310.method_1551().field_1724;
            if (player == null || player.method_7325()) {
                return false;
            }
            IClientPlayerGunOperator operator = IClientPlayerGunOperator.fromLocalPlayer(player);
            if (operator.isAim()) {
                ClientPlayNetworking.send(ClientMessagePlayerZoom.INSTANCE);
                return true;
            }
        }
        return false;
    }

    private static void doZoomLogic() {
        class_746 player = class_310.method_1551().field_1724;
        if (player == null || player.method_7325()) {
            return;
        }
        IClientPlayerGunOperator operator = IClientPlayerGunOperator.fromLocalPlayer(player);
        if (operator.isAim()) {
            ClientPlayNetworking.send(ClientMessagePlayerZoom.INSTANCE);
        }
    }
}
